@@ -222,9 +222,9 @@ class VirtualService(BaseKempObject):
             return 'Virtual Service {} {}:{} on LoadMaster {}'.format(
                 self.prot.upper(), self.vs, self.port, self.ip_address)
 
-    @property
-    def rs(self):
-        return {int(rs.rsindex): rs for rs in self.get_real_servers()}
+    #@property
+    #def rs(self):
+        #return {int(rs.rsindex): rs for rs in self.get_real_servers()}
 
     def to_api_dict(self):
         api = super(VirtualService, self).to_api_dict()
